"""
Console script entry points for CLI tools.
"""
import io
import os
from datetime import datetime
from collections import defaultdict

from edosl0util import split, trunc, stream


def _timestamp(v):
    return datetime.strptime(v, '%Y-%m-%d %H:%M:%S')


def cmd_trunc():
    from argparse import ArgumentParser
    parser = ArgumentParser()
    parser.add_argument('-o', '--output')
    parser.add_argument('filename')
    parser.add_argument('start', type=_timestamp)
    parser.add_argument('end', type=_timestamp)
    args = parser.parse_args()

    output = args.output or os.path.basename(args.filename) + '.trunc'
    with io.open(output, 'wb') as fptr:
        for pkt in trunc.trunc_file(args.filename, args.start, args.end):
            fptr.write(pkt.bytes())


def cmd_split():
    from argparse import ArgumentParser
    parser = ArgumentParser()
    parser.add_argument('--minutes', type=int, default=6)
    parser.add_argument('filepath')
    args = parser.parse_args()

    for stamp, fpath in split.split_file(args.filepath, args.minutes, os.getcwd()):
        print('wrote bucket {} to {}'.format(stamp.isoformat(), fpath))


def cmd_info():
    from argparse import ArgumentParser
    parser = ArgumentParser(description=split.__doc__)
    parser.add_argument('filepath')
    args = parser.parse_args()

    packets = stream.PacketStream(io.open(args.filepath, 'rb'))

    first = datetime(2016, 1, 1)
    last = datetime(2000, 1, 1)
    apids = defaultdict(lambda: {'count': 0})
    for p in packets:
        if p.stamp:
            first = min(first, p.stamp)
            last = max(last, p.stamp)
        apids[p.apid]['count'] += 1

    print "First:", first
    print "Last:", last
    total = 0
    for apid in sorted(apids):
        count = apids[apid]['count']
        total += count
        print "{}: {}".format(apid, count)
    print "{} total packets".format(total)
